# THIS FILE IS GENERATED FROM SETUP.PY
short_version = '0.46.1'
version = '0.46.1'
full_version = '0.46.1'
git_revision = '37b6665779403b9462d27858ef80ae7b2b2454c5'
release = True
if not release:
    version = full_version
